/*
 * @(#)HelpFrame.java       1.00 2000/05/05
 *
 */

import java.awt.*;
import java.awt.event.*;

/**
 * Okno pro zobrazeni napovedy
 *
 * @version 1.00 2000/05/10
 * @author Martin Kot
 */
public class HelpFrame extends Frame {
    /** Panel pro zobrazovani textovych poli s napovedou */
    private Panel panelCard;
    /** Layout pro prepinani mezi dvemi kartami napovedy ("About",
     *  "Game help")
     */
    private CardLayout cardLayout;

    /** Symbolicka konstanta pro oznaceni stranky napovedy */
    public static final int GAME_HELP = 1;
    /** Symbolicka konstanta pro oznaceni stranky o programu */
    public static final int ABOUT = 2;

    /** Vyska textoveho pole */
    protected static int TEXT_HEIGHT = 15;
    /** Sirka textoveho pole */
    protected static int TEXT_WIDTH = 40;
    /** Vyska okna napovedy */
    protected static int FRAME_HEIGHT = 330;
    /** Sirka okna napovedy */
    protected static int FRAME_WIDTH = 300;

    /** Text o programu */
    protected static String aboutText =
        "Gallows Game\n\n" + 
        "Copyright (C)  Martin Kot\n\n" +
        "Version 1.00\n" +
        "Date 2000/05/07\n\n\n" +
        "Made for subject Java Technology\n" +
        "at Technical University Ostrava";

    /** Text napovedy k programu */
    protected static String helpText =
        "Gallows Game\n\n" +
        "Rules of the game:\n" +
        "Target of this game is to find one word.\n" +
        "It can be only noun in singular.\n" +
        "Computer chooses this word and changes\n" +
        "all letters to character *. Then you are going\n" +
        "to guess letters. If the word includes letter,\n" +
        "it will be shown. Othervise the count of wrong\n" +
        "attemps will be increased.\n" +
        "How to win:\n" +
        "\tFind the whole word.\n" +
        "How to lose:\n" +
        "\tThe count of wrong attemps is 9\n\n" +
        "Controls:\n" +
        "Try a letter - click on corresponding\n" +
        "                button\n" +
        "\t- press corresponding key\n" +
        "\t- select corresponding button with \n" +
        "\t  <tablet> key and then press <space>\n" +
        "To surender - select Game - Show solution\n" +
        "\t\tfrom menu.\n" +
        "New game - select Game - New game from\n" +
        "\t\tmenu\n";


    /**
     * Konstruktor
     *
     * @param page Stranka, ktera bude po vytvoreni napovedy zobrazana jako
     * prvni
     *
     */
    public HelpFrame(int page) {
        //Vytvori nove okno s nadpisem
        super("Gallows Game - Help");


        //Panel s tlacitky na meneni stranek
        Panel buttonPanel;
        //Tlacitko pro stranku s napovedou ke hre
        Button buttonHelp;
        //Tlacitko pro informace o hre
        Button buttonAbout;
        //Panel s napovedou ke hre
        Panel panelHelp;
        //Panel s textem o programu
        Panel panelAbout;
        //Textove pole s textem o programu
        TextArea textAbout;
        //Textove pole s textem napovedy ke hre
        TextArea textHelp;
        //Posluchac udalosti od tlacitek
        ActionListener actListener;


        //Nastavi vlastnosti okna
        setLayout(new BorderLayout(10,10));
        setSize(FRAME_WIDTH,FRAME_HEIGHT);
        setResizable(false);

        panelCard = new Panel();

        //Vytvoreni panelu s tlacitky na zmenu stranek
        buttonPanel = new Panel();
        buttonPanel.setLayout(new FlowLayout());
        buttonHelp = new Button("Game help");
        buttonAbout = new Button("About");
        buttonPanel.add(buttonHelp);
        buttonPanel.add(buttonAbout);

        //Vytvoreni panelu o programu
        panelAbout = new Panel();
        panelAbout.setLayout(new GridLayout(1,1,0,0));
        textAbout = new TextArea(TEXT_HEIGHT,TEXT_WIDTH);
        textAbout.setText(aboutText);
        textAbout.setEditable(false);
        panelAbout.add(textAbout);

        //Vytvoreni panelu napovedy
        panelHelp = new Panel();
        panelHelp.setLayout(new GridLayout(1,1,0,0));
        textHelp = new TextArea(TEXT_HEIGHT,TEXT_WIDTH);
        textHelp.setText(helpText);
        textHelp.setEditable(false);
        panelHelp.add(textHelp);

        //Vytvoreni layoutu na prepinani mezi strankami helpu
        cardLayout = new CardLayout();
        panelCard.setLayout(cardLayout);
        panelCard.add(panelHelp,"Game help");
        panelCard.add(panelAbout,"About");
        if (page == GAME_HELP) {
            cardLayout.first(panelCard);
            buttonHelp.requestFocus();
        }
        else {
            buttonAbout.requestFocus();
            cardLayout.last(panelCard);
        }

        //Pridani posluchace na udalosti od tlacitek na meneni stranek
        actListener = new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                if (e.getActionCommand() == "Game help") {
                    cardLayout.first(panelCard);
                }
                else if (e.getActionCommand() == "About") {
                    cardLayout.last(panelCard);
                }
            }
        };
        buttonHelp.addActionListener(actListener);
        buttonAbout.addActionListener(actListener);
        add("North",buttonPanel);
        add("Center",panelCard);

        //Vytvoreni posluchace na obsluhu uzavreni okna
        addWindowListener(
            new WindowAdapter() {
                public void windowClosing(WindowEvent e) {
                    dispose();
                 }
            });

        show();
    }

    /**
     * Konstruktor bez parametru
     * Implicitne je nastavena stranka s napovedou ke hre
     *
     */
    public HelpFrame() {
        this(GAME_HELP);
    }
}
