/*
 * @(#)LetterButtonsPanel.java       1.00 2000/05/05
 *
 */


import java.awt.*;
import java.awt.event.*;

/**
 * Panel s tlacitky anglicke abecedy
 *
 * @version 1.00 2000/05/23
 * @author Martin Kot
 */
public class LetterButtonsPanel extends Panel {

    /** Rozmery pro panel s tlacitky s pismeny*/
    protected static Rectangle PANEL_BUTTONS_DIM 
        = new Rectangle(5, 120, 440, 70);

    /** Pocet znaku, na ktere budou utvoreny tlacitka */
    public static int CHARS_COUNT = 26;

    /** Hra sibenice, k niz tento objekt dela rozhrani */
    protected GallowsGame galGame;

    /** Pole tlacitek s pismeny */
    protected Button[] buttons;

    /** Posluchac udalosti tlacitek a menu */
    protected ActionListener actListener;


    /**
     * Konstruktor
     *
     * @param galGame objekt, pro ktery dela applet, uzivajici tento objekt,
     * rozhrani
     *
     */
    public LetterButtonsPanel(GallowsGame galGame) {
        super();

        this.galGame = galGame;
        setBounds(PANEL_BUTTONS_DIM);
        setLayout(new GridLayout(2,(CHARS_COUNT / 2),2,2));
        buttons = new Button['Z'-'A'+1];
        for (int i = 'A'; i <= 'Z'; i++) {
            buttons[i-'A'] = new Button(String.valueOf((char) i));
            this.add(buttons[i-'A']);
        }

        //Vytvoreni posluchace na obsluhu akci od tlacitek 
        actListener
            = new ActionListener() {
                public void actionPerformed (ActionEvent ae) {
                    String command = ae.getActionCommand();
                    for (int i = 0; i < buttons.length; i++) {
                        if (buttons[i].getLabel().compareTo(command) == 0) {
                            if (buttons[i].isEnabled()) {
                                buttons[i].setEnabled(false);
                                tryChar(command.charAt(0));
                            }
                        }
                    }
                }
            };

        //Vytvoreni posluchace udalosti z klavesnice
        KeyListener k = new KeyListener() {
            public void keyReleased(KeyEvent ke) {
            }
        
            public void keyPressed(KeyEvent ke) {
            }

            //Po stisku klavesy z anglicke abecedy vyvola udalost jako
            //pri stisku odpovidajiciho tlacitka
            public void keyTyped(KeyEvent ke) {
                int index;
                char keyChar = ke.getKeyChar();
                if (keyChar != KeyEvent.CHAR_UNDEFINED &&
                      ((keyChar >= 'a' && keyChar <='z') ||
                       (keyChar >= 'A' && keyChar <='Z'))) {
                    keyChar = Character.toUpperCase(keyChar);
                    index = keyChar - 'A';
                    buttons[index].dispatchEvent(new ActionEvent(
                        buttons[index], Event.ACTION_EVENT,
                        buttons[index].getLabel()));
                    buttons[index].requestFocus();
                }
            }
        };

        for (int i = 0; i < buttons.length; i++) {
            buttons[i].addActionListener(actListener);
            buttons[i].addKeyListener(k);
        }
        addKeyListener(k);
        buttons[0].requestFocus();
    }


    /**
     * Vola metodu tryChar na GallowsGame
     *
     * @param c znak, ktery bude metodou tryChar tridy GallowsGame testovan
     */
    protected void tryChar(char c) {
        try {
            galGame.tryChar(c);
        } catch (ToMuchAttempsException e) {}
    }    


    /**
     * Nastavi vsechny tlacitka na funkcni nebo nefunkcni
     *
     * @param state true  - tlacitka budou nastavena na funkcni
     *              false - tlacitka budou nastavena na nefunkcni
     *
     */
    public void setButtons(boolean state) {
        for (int i = 0; i < buttons.length; i++) {
            buttons[i].setEnabled(state);
        }
    }

    /**
     * Pozada o zamereni na prvni tlacitko
     *
     */
    public void requestButtonFocus() {
        buttons[0].requestFocus();
    }
}
















