/*
 * @(#)MakeWordList       1.10 2000/05/10
 *
 */

import java.io.*;

/**
 * Trida pro tvorbu souboru se slovy k hadani
 *
 * @version    1.10 2000/05/10
 * @author     Martin Kot
 *
 */
public class MakeWordList{

    /** Soubor, kam se slova ukladaji */ 
    protected File wordListFile;

    /**
     * Konstruktor
     *
     * @param fileName jmeno souboru, kam se slova ulozi
     *
     */
    public MakeWordList(String fileName) {
        wordListFile = new File(fileName);
    }

    /**
     * Konstruktor bez parametru. Za jmeno souboru je zvolen
     * retezec "default.txt"
     *
     * @param fileName jmeno souboru, kam se slova ulozi
     *
     */
    public MakeWordList() {
        this("default.txt");
    }


    /**
     * Metoda kontroluje, zda se slovo v souboru jiz nachazi
     *
     * @param word slovo, ktere je v souboru hledano
     * @return false je-li slovo jiz v souboru obsazeno
     *         true  neni-li slovo jeste v souboru
     *
     */
    protected boolean checkWord(String word) throws IOException{

        int wordsCount =
             (int) wordListFile.length()
                  / ((GallowsGame.WORD_LENGTH + 1) * 2);
        RandomAccessFile wordList=new RandomAccessFile(wordListFile,"rw");
        char c;
        StringBuffer oldWord;

        for(int i = 0; i < wordsCount; i++) {
            oldWord = new StringBuffer(GallowsGame.WORD_LENGTH+1);
            for(int j = 0; j < (GallowsGame.WORD_LENGTH + 1); j++) {
                c = wordList.readChar();
                if (c != ' ') {
                    oldWord.append(c);
                }
            }
            if (word.compareTo(oldWord.toString()) == 0) {
                wordList.close();
                return false;
            }
        }
        wordList.close();
        return true;
    }


    /**
     * Ulozi jedno slovo na konec souboru
     *
     * @param newWord retezcova reprezentace slova pridavaneho do souboru
     *
     */
    protected void saveWord(String newWord) throws FileNotFoundException,
                                                   IOException {
            RandomAccessFile wordList=new RandomAccessFile(wordListFile,"rw");
            wordList.seek(wordList.length());
            wordList.writeChars(newWord);
            wordList.writeChar(' ');
            wordList.close();
    }

    /**
     * Pridava jedno slovo na konec souboru se slovy
     *
     * @param newWord retezcova reprezentace pridavaneho slova
     * @exception FileNotFoundException jestlize dany soubor neexistuje
     * @exception IOException pri ostatnich chybach pri praci se souborem
     *
     */
    public void addWord(String newWord) throws FileNotFoundException,
                                               IOException {
        if (checkWord(newWord)) {
            StringBuffer savedWord
                = new StringBuffer(GallowsGame.WORD_LENGTH + 1);

            savedWord.append(newWord);
            for (int i = savedWord.length() + 1; i < savedWord.capacity();
                    i++) {
                savedWord.append(' ');
            }
            saveWord(savedWord.toString());
        }
    }


    /**
     * Cte slova ze standardniho vstupu a po kontrole je zapisuje do souboru
     *
     */
    protected void readWords() {
        BufferedReader d = new BufferedReader(
            new InputStreamReader(System.in));
        String s = " ";

        while(s.length() != 0) {
            System.out.println("\nWrite new word (press <enter> to end):");
            try {
                s = d.readLine();
            } catch(Exception e) {
                System.out.println("Error by reading from standart input");
            }
            s = s.toUpperCase();
            if (s.length() != 0) {
                if (s.length() < 3) {
                    System.out.println("\"" + s + "\"" + " is to short!");
                } else if (s.length() > GallowsGame.WORD_LENGTH) {
                    System.out.println("\"" + s + "\"" + " is to long!");
                } else if (checkChars(s)) {
                    try {
                        addWord(s);
                    } catch (Exception e) {
                        System.out.println("Error by working with file");
                    }
                }
                else {
                    System.out.println("In word \"" + s 
                        + "\" are incorect characters");
                }
            }
        }
    }

    /**
     * Kontroluje, zda ve slove jsou jen pismena anglicke abecedy
     *
     * @param newWord retezcova reprezentace pridavaneho slova
     * @exception FileNotFoundException jestlize dany soubor neexistuje
     * @exception IOException pri ostatnich chybach pri praci se souborem
     *
     */
    protected boolean checkChars(String word) {
        for (int i = 0; i < word.length(); i++) {
            if (word.charAt(i) < 'A' ||  word.charAt(i) > 'Z') {
                return false;
            }
        }
        return true;
    }



    /**
     * Umoznuje zapisovat slova do slovniku
     *
     * @param args pole argumentu prikazove radky
     *
     */
    public static void main(String args[]){
        MakeWordList mwl = new MakeWordList(GallowsApplet.FILE_NAME);
        mwl.readWords();
        
    }

}

